<?php
// Copyright (C) <2015>  <it-novum GmbH>
//
// This file is dual licensed
//
// 1.
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, version 3 of the License.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// 2.
//  If you purchased an openITCOCKPIT Enterprise Edition you can use this file
//  under the terms of the openITCOCKPIT Enterprise Edition license agreement.
//  License agreement and license key will be shipped with the order
//  confirmation.

namespace LinuxBasicMonitoringSSHModule\Lib\InitialDatabase;

use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package LinuxBasicMonitoringSSHModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {
    public function __construct() {
        $TemplateImporter = new \App\itnovum\openITCOCKPIT\ImportTemplates\TemplateImport(
            \Cake\ORM\TableRegistry::getTableLocator()->get('Commands'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Macros'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Hosttemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplategroups')
        );
        $TemplateImporter->import($this->getData());
    }

    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Macros'                => $this->getMacrosData(),
            'Hosttemplates'         => $this->getHosttemplatesData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 =>
                [
                    'name'             => 'check_by_ssh_disk',
                    'command_line'     => '$USER1$/check_by_ssh -H $HOSTADDRESS$ -l nagios -C "/usr/lib/nagios/plugins/check_disk -w $ARG1$ -c $ARG2$ -p $ARG3$" -o StrictHostKeyChecking=no',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => 'ca2a30b8-2e17-4986-96f7-1383a165b79b',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning less free space',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical less free space',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Path',
                                ],
                        ],
                ],
            1 =>
                [
                    'name'             => 'check_by_ssh_load',
                    'command_line'     => '$USER1$/check_by_ssh -H $HOSTADDRESS$ -l nagios -C "/usr/lib/nagios/plugins/check_load -w $ARG1$ -c $ARG2$" -o StrictHostKeyChecking=no',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => 'd655aae8-d822-44e5-9e1e-851e307e1f2c',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning load',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical load',
                                ],
                        ],
                ],
            2 =>
                [
                    'name'             => 'check_by_ssh_procs_string',
                    'command_line'     => '$USER1$/check_by_ssh -H $HOSTADDRESS$ -l nagios -C "/usr/lib/nagios/plugins/check_procs -w $ARG1$ -c $ARG2$ -a $ARG3$" -o StrictHostKeyChecking=no',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '1ffcab3f-a2d6-41bc-8f98-8e190d9c7f76',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'Processname',
                                ],
                        ],
                ],
            3 =>
                [
                    'name'             => 'check_by_ssh_swap',
                    'command_line'     => '$USER1$/check_by_ssh -H $HOSTADDRESS$ -l nagios -C "/usr/lib/nagios/plugins/check_swap -w $ARG1$ -c $ARG2$" -o StrictHostKeyChecking=no',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => 'fa175972-498f-43ec-b2d3-2d457730544b',
                    'description'      => '',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning less free swap space',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical less free swap space',
                                ],
                        ],
                ],
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getMacrosData() {
        $data = [
            /*
            [
                'name'        => '$USER1$',
                'value'       => 'foo',
                'description' => 'bar',
                'password'    => '0',
                'created'     => '2020-05-13 14:11:30',
                'modified'    => '2020-05-13 14:11:30'
            ],
            [
                'name'        => '$USER2$',
                'value'       => 'bar',
                'description' => 'baz',
                'password'    => '0',
                'created'     => '2020-05-13 14:11:41',
                'modified'    => '2020-05-13 14:11:41'
            ]
            */
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getHosttemplatesData() {
        $data = [
            /*
            [
                'id'                                => '2',
                'uuid'                              => 'd2f712ef-fc7e-4004-9bdc-8c819f00fff',
                'name'                              => 'My Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ],
            [
                'id'                                => '3',
                'uuid'                              => '82e7245a-f1be-41cd-b074-ff88681f7fff',
                'name'                              => 'Another Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ]
            */
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0 =>
                [
                    'uuid'                                      => '7e16811f-f37a-476c-be42-94bd6f5cadcb',
                    'template_name'                             => 'LINUX_BY_SSH_DISK',
                    'name'                                      => 'Disk Usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'ca2a30b8-2e17-4986-96f7-1383a165b79b',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => null,
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:23:08',
                    'modified'                                  => '2018-09-21 14:23:08',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '20%',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '10%',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            1 =>
                [
                    'uuid'                                      => 'c8eaf308-2fce-4e29-9565-00639fa2dc4c',
                    'template_name'                             => 'LINUX_BY_SSH_DISK_ROOT',
                    'name'                                      => 'Disk Usage /',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'ca2a30b8-2e17-4986-96f7-1383a165b79b',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:23:22',
                    'modified'                                  => '2018-09-21 14:23:59',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '20%',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '10%',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            2 =>
                [
                    'uuid'                                      => '7eb4f621-1090-4369-bc1d-5cf2543f5388',
                    'template_name'                             => 'LINUX_BY_SSH_LOAD',
                    'name'                                      => 'LinuxLoad',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'd655aae8-d822-44e5-9e1e-851e307e1f2c',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '120',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:24:36',
                    'modified'                                  => '2018-09-21 14:25:21',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '4,3,2',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '5,4,3',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            3 =>
                [
                    'uuid'                                      => '1fab2049-17ac-46e7-869e-09d149f13c8f',
                    'template_name'                             => 'LINUX_BY_SSH_PROCESS',
                    'name'                                      => 'Process',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '1ffcab3f-a2d6-41bc-8f98-8e190d9c7f76',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '120',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:25:43',
                    'modified'                                  => '2018-09-21 14:26:05',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1:',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '1:',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            4 =>
                [
                    'uuid'                                      => '901f22be-f6a5-487a-9400-581ccc9b0792',
                    'template_name'                             => 'LINUX_BY_SSH_SWAP',
                    'name'                                      => 'Swap Usage',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => 'fa175972-498f-43ec-b2d3-2d457730544b',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '120',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2018-09-21 14:26:22',
                    'modified'                                  => '2018-09-21 14:26:41',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '80%',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '50%',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 =>
                [
                    'uuid'             => '96dd3d64-6d89-4fca-9346-1724fb5b57dd',
                    'description'      => '',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => 'c8eaf308-2fce-4e29-9565-00639fa2dc4c',
                                    'uuid' => 'c8eaf308-2fce-4e29-9565-00639fa2dc4c',
                                ],
                            1 =>
                                [
                                    'id'   => '7eb4f621-1090-4369-bc1d-5cf2543f5388',
                                    'uuid' => '7eb4f621-1090-4369-bc1d-5cf2543f5388',
                                ],
                            2 =>
                                [
                                    'id'   => '901f22be-f6a5-487a-9400-581ccc9b0792',
                                    'uuid' => '901f22be-f6a5-487a-9400-581ccc9b0792',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'Linux Basic Monitoring SSH',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
        ];
        return $data;
    }
}
